@@ -28,7 +28,7 @@ sub form_validation_done {
   my $model = shift;
   my $input_profile = {
 		       required => [ qw( email phone likes ) ],
-		       optional => [ qq( toppings ) ],
+		       optional => [ qw( toppings ) ],
 		       constraints => {
 				       email => "email",
 				       phone => "phone",
@@ -162,7 +162,7 @@ It is a good starting point for building your backend for your PageKit website.
 
 T.J. Mather (tjmather@thoughtstore.com)
 
-Boris Zentner (boris@m2b.de)
+Boris Zentner (boris@id9.de)
 
 =head1 COPYRIGHT
 
